@@ -43,6 +43,8 @@ func commentCmd(ctx *config.RunContext) *cobra.Command {
 	for _, subCmd := range cmds {
 		subCmd.Flags().StringArray("policy-path", nil, "Path to Infracost policy files, glob patterns need quotes (experimental)")
 		subCmd.Flags().Bool("show-all-projects", false, "Show all projects in the table of the comment output")
+		subCmd.Flags().Bool("show-changed", false, "Show only projects in the table that have code changes")
+		_ = subCmd.Flags().MarkHidden("show-changed")
 	}
 
 	cmd.AddCommand(cmds...)
@@ -96,6 +98,7 @@ func buildCommentBody(cmd *cobra.Command, ctx *config.RunContext, paths []string
 		GuardrailCheck:    guardrailCheck,
 	}
 	opts.ShowAllProjects, _ = cmd.Flags().GetBool("show-all-projects")
+	opts.ShowOnlyChanges, _ = cmd.Flags().GetBool("show-changed")
 
 	b, err := output.ToMarkdown(combined, opts, mdOpts)
 	if err != nil {
