@@ -83,9 +83,12 @@ func commentGitLabCmd(ctx *config.RunContext) *cobra.Command {
 				IncludeFeedbackLink: true,
 			})
 			var policyFailure output.PolicyCheckFailures
+			var guardrailFailure output.GuardrailFailures
 			if err != nil {
 				if v, ok := err.(output.PolicyCheckFailures); ok {
 					policyFailure = v
+				} else if v, ok := err.(output.GuardrailFailures); ok {
+					guardrailFailure = v
 				} else {
 					return err
 				}
@@ -113,6 +116,9 @@ func commentGitLabCmd(ctx *config.RunContext) *cobra.Command {
 			if policyFailure != nil {
 				return policyFailure
 			}
+			if guardrailFailure != nil {
+				return guardrailFailure
+			}
 
 			return nil
 		},
