@@ -14,6 +14,8 @@ import (
 	"github.com/infracost/infracost/internal/logging"
 )
 
+const InfracostDir = ".infracost"
+
 // Project defines a specific terraform project config. This can be used
 // specify per folder/project configurations so that users don't have
 // to provide flags every run. Fields are documented below. More info
@@ -100,6 +102,7 @@ type Config struct {
 	SyncUsageFile   bool       `yaml:"sync_usage_file,omitempty" ignored:"true"`
 	Fields          []string   `yaml:"fields,omitempty" ignored:"true"`
 	CompareTo       string
+	GitDiffTarget   *string
 
 	// Base configuration settings
 	// RootPath defines the raw value of the `--path` flag provided by the user
@@ -148,7 +151,7 @@ func DefaultConfig() *Config {
 // RepoPath returns the filepath to either the config-file location or initial path provided by the user.
 func (c *Config) RepoPath() string {
 	if c.ConfigFilePath != "" {
-		return c.ConfigFilePath
+		return strings.TrimRight(c.ConfigFilePath, filepath.Base(c.ConfigFilePath))
 	}
 
 	return c.RootPath
