@@ -233,6 +233,7 @@ type Options struct {
 	NoColor           bool
 	ShowSkipped       bool
 	ShowAllProjects   bool
+	ShowOnlyChanges   bool
 	Fields            []string
 	IncludeHTML       bool
 	PolicyChecks      PolicyCheck
@@ -266,7 +267,7 @@ func (p PolicyCheckFailures) Error() string {
 	out := bytes.NewBuffer([]byte("Policy check failed:\n\n"))
 
 	for _, e := range p {
-		out.WriteString(e + "\n")
+		out.WriteString(" - " + e + "\n")
 	}
 
 	return out.String()
@@ -301,7 +302,7 @@ func (g GuardrailFailures) Error() string {
 	out := bytes.NewBuffer([]byte("Guardrail check failed:\n\n"))
 
 	for _, e := range g {
-		out.WriteString(e + "\n")
+		out.WriteString(" - " + e + "\n")
 	}
 
 	return out.String()
