@@ -1,7 +1,6 @@
 package terraform
 
 import (
-	"strings"
 	"sync"
 
 	"github.com/infracost/infracost/internal/schema"
@@ -93,10 +92,6 @@ func GetUsageOnlyResources() []string {
 	return r
 }
 
-func HasSupportedProvider(rType string) bool {
-	return strings.HasPrefix(rType, "aws_") || strings.HasPrefix(rType, "google_") || strings.HasPrefix(rType, "azurerm_")
-}
-
 func createFreeResources(l []string, defaultRefsFunc schema.ReferenceIDFunc, resourceIdFunc schema.CloudResourceIDFunc) []*schema.RegistryItem {
 	freeResources := make([]*schema.RegistryItem, 0)
 	for _, resourceName := range l {
