@@ -2,6 +2,7 @@ package aws
 
 import (
 	"context"
+	"math"
 
 	"github.com/infracost/infracost/internal/resources"
 	"github.com/infracost/infracost/internal/schema"
@@ -19,7 +20,7 @@ type AutoscalingGroup struct {
 	LaunchTemplate      *LaunchTemplate
 }
 
-var AutoscalingGroupUsageSchema = append([]*schema.UsageSchemaItem{
+var AutoscalingGroupUsageSchema = append([]*schema.UsageItem{
 	{Key: "instances", DefaultValue: 0, ValueType: schema.Int64},
 }, InstanceUsageSchema...)
 
@@ -40,7 +41,7 @@ func (a *AutoscalingGroup) PopulateUsage(u *schema.UsageData) {
 // as the default value for the "instances" usage param.  Without this, --sync-usage-file sets instances=0 causing the
 // costs for the node group to be $0.  This can be removed when --sync-usage-file creates the usage file with usgage keys
 // commented out by default.
-func (a *AutoscalingGroup) getUsageSchemaWithDefaultInstanceCount() []*schema.UsageSchemaItem {
+func (a *AutoscalingGroup) getUsageSchemaWithDefaultInstanceCount() []*schema.UsageItem {
 	var instanceCount *int64
 	if a.LaunchConfiguration != nil {
 		instanceCount = a.LaunchConfiguration.InstanceCount
@@ -52,10 +53,10 @@ func (a *AutoscalingGroup) getUsageSchemaWithDefaultInstanceCount() []*schema.Us
 		return AutoscalingGroupUsageSchema
 	}
 
-	usageSchema := make([]*schema.UsageSchemaItem, 0, len(AutoscalingGroupUsageSchema))
+	usageSchema := make([]*schema.UsageItem, 0, len(AutoscalingGroupUsageSchema))
 	for _, u := range AutoscalingGroupUsageSchema {
 		if u.Key == "instances" {
-			usageSchema = append(usageSchema, &schema.UsageSchemaItem{Key: "instances", DefaultValue: instanceCount, ValueType: schema.Int64})
+			usageSchema = append(usageSchema, &schema.UsageItem{Key: "instances", DefaultValue: intVal(instanceCount), ValueType: schema.Int64})
 		} else {
 			usageSchema = append(usageSchema, u)
 		}
@@ -99,7 +100,7 @@ func (a *AutoscalingGroup) BuildResource() *schema.Resource {
 				return err
 			}
 			if count > 0 {
-				u["instances"] = int64(count)
+				u["instances"] = int64(math.Round(count))
 			}
 		}
 		return nil
